@@ -1,5 +1,4 @@
 __all__ = ["module",
            "podfile",
            "target",
-           "util",
-           "podspec"]
\ No newline at end of file
+           "util"]
\ No newline at end of file
